@@ -15,15 +15,15 @@
 #include "socket.h"
 
 #ifndef SOURCE_VERSION
-#define SOURCE_VERSION "2022.0"
+#define SOURCE_VERSION "2022.1"
 #endif
 
 static void usage(const char *prgname)
 {
 	fprintf(stderr, "Usage:\n");
-	fprintf(stderr, "%s interface image\t\t\tflash router with given image\n",
+	fprintf(stderr, "%s interface image\t\t\tflash device with given image\n",
 		prgname);
-	fprintf(stderr, "%s [-m <MAC>...] interface image\tflash router at given MAC address(es)\n", prgname);
+	fprintf(stderr, "%s [-m <MAC>...] interface image\tflash device at given MAC address(es)\n", prgname);
 	fprintf(stderr, "%s -h\t\t\t\t\tshow usage/help\n", prgname);
 	fprintf(stderr, "%s -v\t\t\t\t\tprints version information\n", prgname);
 
