@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
- * SPDX-FileCopyrightText: 2009-2019, Marek Lindner <mareklindner@neomailbox.ch>
+ * SPDX-FileCopyrightText: Marek Lindner <mareklindner@neomailbox.ch>
  */
 
 #ifndef __AP51_FLASH_FLASH_H__
@@ -7,6 +7,7 @@
 
 #include <stdint.h>
 
+#include "list.h"
 #include "proto.h"
 
 enum flash_mode {
@@ -29,6 +30,7 @@ enum node_status {
 };
 
 struct node {
+	struct list_head list;
 	uint8_t his_mac_addr[6];
 	uint8_t our_mac_addr[6];
 	uint32_t his_ip_addr;
