@@ -66,7 +66,7 @@ static int redboot_8mb_detect(struct node *node)
 		goto out;
 
 #if defined(DEBUG)
-	fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: flash size of 8 MB was detected ...\n",
+	fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: %s: flash size of 8 MB was detected ...\n",
 		node->his_mac_addr[0], node->his_mac_addr[1],
 		node->his_mac_addr[2], node->his_mac_addr[3],
 		node->his_mac_addr[4], node->his_mac_addr[5],
@@ -87,7 +87,7 @@ static int redboot_4mb_detect(struct node (*node)__attribute__((unused)))
 {
 	/* default redboot type */
 #if defined(DEBUG)
-	fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: flash size of 4 MB was detected (default) ...\n",
+	fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: %s: flash size of 4 MB was detected (default) ...\n",
 		node->his_mac_addr[0], node->his_mac_addr[1],
 		node->his_mac_addr[2], node->his_mac_addr[3],
 		node->his_mac_addr[4], node->his_mac_addr[5],
@@ -164,7 +164,7 @@ void redboot_main(struct node *node, const char *telnet_msg)
 							FLASH_PAGE_SIZE) * FLASH_PAGE_SIZE;
 
 		if (redboot_priv->redboot_type->flash_size < req_flash_size) {
-			fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: image size '%s' of 0x%08lx exceeds router capacity: 0x%08lx\n",
+			fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: %s: image size '%s' of 0x%08lx exceeds device capacity: 0x%08lx\n",
 				node->his_mac_addr[0], node->his_mac_addr[1],
 				node->his_mac_addr[2], node->his_mac_addr[3],
 				node->his_mac_addr[4], node->his_mac_addr[5],
@@ -179,7 +179,7 @@ void redboot_main(struct node *node, const char *telnet_msg)
 			((unsigned char *)&node->our_ip_addr)[0], ((unsigned char *)&node->our_ip_addr)[1],
 			((unsigned char *)&node->our_ip_addr)[2], ((unsigned char *)&node->our_ip_addr)[3]);
 
-		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: setting IP address ...\n",
+		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s: setting IP address ...\n",
 		       node->his_mac_addr[0], node->his_mac_addr[1],
 		       node->his_mac_addr[2], node->his_mac_addr[3],
 		       node->his_mac_addr[4], node->his_mac_addr[5],
@@ -205,7 +205,7 @@ void redboot_main(struct node *node, const char *telnet_msg)
 			goto redboot_failure;
 		}
 
-		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: initializing partitions ...\n",
+		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s: initializing partitions ...\n",
 		       node->his_mac_addr[0], node->his_mac_addr[1],
 		       node->his_mac_addr[2], node->his_mac_addr[3],
 		       node->his_mac_addr[4], node->his_mac_addr[5],
@@ -223,7 +223,7 @@ void redboot_main(struct node *node, const char *telnet_msg)
 			redboot_priv->redboot_type->kernel_load_addr,
 			redboot_priv->redboot_type->kernel_load_addr);
 
-		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: flashing kernel ...\n",
+		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s: flashing kernel ...\n",
 		       node->his_mac_addr[0], node->his_mac_addr[1],
 		       node->his_mac_addr[2], node->his_mac_addr[3],
 		       node->his_mac_addr[4], node->his_mac_addr[5],
@@ -251,7 +251,7 @@ void redboot_main(struct node *node, const char *telnet_msg)
 			redboot_priv->redboot_type->flash_addr + file_info->file_fsize,
 			redboot_priv->redboot_type->flash_size - file_info->file_fsize);
 
-		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: flashing rootfs ...\n",
+		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s: flashing rootfs ...\n",
 		       node->his_mac_addr[0], node->his_mac_addr[1],
 		       node->his_mac_addr[2], node->his_mac_addr[3],
 		       node->his_mac_addr[4], node->his_mac_addr[5],
@@ -261,7 +261,7 @@ void redboot_main(struct node *node, const char *telnet_msg)
 		redboot_priv->redboot_state = REDBOOT_STATE_FL_ROOTFS;
 		break;
 	case REDBOOT_STATE_FL_ROOTFS:
-		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s router: setting boot_script_data ...\n",
+		printf("[%02x:%02x:%02x:%02x:%02x:%02x]: %s: setting boot_script_data ...\n",
 		       node->his_mac_addr[0], node->his_mac_addr[1],
 		       node->his_mac_addr[2], node->his_mac_addr[3],
 		       node->his_mac_addr[4], node->his_mac_addr[5],
