@@ -47,13 +47,14 @@ static const struct router_type *router_types[] = {
 	&p60.router_type,
 	&redboot,
 	&tw420.router_type,
-	&ubnt,
+	&ubnt.router_type,
 	&zyxel.router_type,
 	&ap121f,
 	&pa300.router_type,
 	&pa1200.router_type,
 	&pa2200.router_type,
 	&pax1800.router_type,
+	&pax1800v2.router_type,
 	NULL,
 };
 
@@ -134,7 +135,7 @@ void router_types_detect_pre(const uint8_t *our_mac)
 		if (!(*router_type)->detect_pre)
 			continue;
 
-		(*router_type)->detect_pre(our_mac);
+		(*router_type)->detect_pre(*router_type, our_mac);
 	}
 }
 
@@ -219,7 +220,7 @@ int router_types_detect_main(struct node *node, const char *packet_buff,
 		ret = 1;
 #endif
 
-		fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: type '%s router' detected\n",
+		fprintf(stderr, "[%02x:%02x:%02x:%02x:%02x:%02x]: device type '%s' detected\n",
 			node->his_mac_addr[0], node->his_mac_addr[1],
 			node->his_mac_addr[2], node->his_mac_addr[3],
 			node->his_mac_addr[4], node->his_mac_addr[5],
